


/*  Tools in Breadcrumbs: Edit Mode, Trash List
------------------------------------------------------------------------------------------------------ */

#breadcrumbs .tools {
    margin: -7px 32px -20px 0;
}

#breadcrumbs .tools > li > a {
    padding: 0;
    width: 20px;
    height: 30px;
    border: 0;
}
#breadcrumbs .tools a.edit-dashboard-toggle-handler:link, #breadcrumbs .tools a.edit-dashboard-toggle-handler:visited {
    background: transparent url('../img/icons/icon-edit-dashboard-toggle-handler.png') 50% 50% no-repeat;
}
#breadcrumbs .tools a.edit-dashboard-toggle-handler:hover, #breadcrumbs .tools a.edit-dashboard-toggle-handler:active, 
#breadcrumbs .tools a.tools-active.edit-dashboard-toggle-handler {
    background: transparent url('../img/icons/icon-edit-dashboard-toggle-handler-hover.png') 50% 50% no-repeat !important;
}

#breadcrumbs .tools a.trash-list-toggle-handler:link, #breadcrumbs .tools a.trash-list-toggle-handler:visited {
    background: transparent url('../img/icons/icon-trash-list-toggle-handler.png') 50% 50% no-repeat;
}
#breadcrumbs .tools a.trash-list-toggle-handler:hover, #breadcrumbs .tools a.trash-list-toggle-handler:active, 
#breadcrumbs .tools a.tools-active.trash-list-toggle-handler {
    background: transparent url('../img/icons/icon-trash-list-toggle-handler-hover.png') 50% 50% no-repeat !important;
}


/*  Trash List ......................................... */

ul.tools li.trash-list-container {
    opacity: 1 !important;
    overflow: visible !important;
}

ul.trash-list {
    position: absolute;
    float: none;
    display: block;
    right: 2px;
    z-index: 900;
    top: 28px;
    min-width: 218px;
    border: 1px solid #ccc;
    border-radius: 4px; -moz-border-radius: 4px; -webkit-border-radius: 4px;
    border-top-right-radius: 0; -moz-border-radius-topright: 0 !important; -webkit-border-top-right-radius: 0;
    border-top-left-radius: 0; -moz-border-radius-topleft: 0 !important; -webkit-border-top-left-radius: 0;
    background: #e6e6e6;
    box-shadow: 0 10px 50px #ccc; -moz-box-shadow: 0 10px 50px #ccc; -webkit-box-shadow: 0 10px 50px #ccc;
}

/* Empty breaks in Chrome 11+: Elements are not displayed initially even if they are not empty */
/*ul.trash-list:empty {
    display: none;
}*/

ul.trash-list li {
    position: relative;
    float: none;
    margin: 0 !important;
    width: 100%;
    border-top: 1px solid #f4f4f4 !important;
    border-bottom: 1px solid #d4d4d4 !important;
}
ul.trash-list li:last-child {
    border-bottom: 0 !important;
}

ul.trash-list li a {
    padding-left: 10px;
    border-radius: 0; -moz-border-radius: 0; -webkit-border-radius: 0;
    background: transparent !important;
    opacity: 1 !important;
}
ul.trash-list li a:link, ul.trash-list li a:visited {
    color: #309bbf;
}
ul.trash-list li a:hover, ul.trash-list li a:active {
    color: #444;
}