<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>blank_page</title>
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
	<script type="text/javascript">
		parent.TemplateDialog.loadCSSFiles(document);
	</script>
</head>
<body id="mceTemplatePreview" class="mceContentBody">

</body>
</html>
