<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <title>{#template_dlg.title}</title>
    <script type="text/javascript" src="../../tiny_mce_popup.js"></script>
    <script type="text/javascript" src="js/template.js"></script>
    <base target="_self" />
</head>
<body onresize="TemplateDialog.resize();" class="tinyMCE"> 
    <form onsubmit="TemplateDialog.insert();return false;">
        <div id="frmbody">
            <div class="title">{#template_dlg.desc}</div>
            <fieldset class="module">
                <div class="row combine">
                    <div class="column span-4"><label for="tpath" title="{#template_dlg.select}">{#template_dlg.label}:</label></div>
                    <div class="column span-flexible">
                        <select id="tpath" name="tpath" onchange="TemplateDialog.selectTemplate(this.options[this.selectedIndex].value, this.options[this.selectedIndex].text);" class="mceFocus">
                            <option value="">{#template_dlg.select}...</option>
                        </select>
                        <span id="warning"></span>
                    </div>
                </div>
                <div class="row description last">
                    <div class="column span-4"><label for="tdesc">{#template_dlg.desc_label}:</label></div>
                    <div class="column span-flexible">
                        <span id="tmpldesc"></span>
                    </div>
                </div>
                <fieldset style="display: none;">
                    <iframe id="templatesrc" name="templatesrc" src="blank.htm" width="260" height="400" frameborder="0"></iframe>
                </fieldset>
            </fieldset>
        </div>
        <div class="mceActionPanel module submit-row">
            <ul class="submit-row">
                <li class="cancel-button-container left"><input type="button" id="cancel" class="cancel" name="cancel" value="{#cancel}" onclick="tinyMCEPopup.close();" /></li>
                <li class="submit-button-container"><input type="submit" id="insert" class="default" name="insert" value="{#insert}" /></li>
            </ul>
        </div>
    </form>
</body> 
</html> 
