<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>blank_page</title>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<link href="css/blank.css" rel="stylesheet" type="text/css" />
<base target="_self" />
<script type="text/javascript">
function init() {
	if (parent.tinymce.isIE)
		document.body.contentEditable = true;
	else
		document.designMode = 'on';

	parent.initIframe(document);
	window.focus();
}
</script>
</head>
<body onload="init();">

</body>
</html>
