<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>{#searchreplace_dlg.replace_title}</title>
	<script type="text/javascript" src="../../tiny_mce_popup.js"></script>
	<script type="text/javascript" src="../../utils/mctabs.js"></script>
	<script type="text/javascript" src="../../utils/form_utils.js"></script>
	<script type="text/javascript" src="js/searchreplace.js"></script>
	<!-- <link rel="stylesheet" type="text/css" href="css/searchreplace.css" /> -->
	<base target="_self" />
</head>
<body style="display:none;" class="tinyMCE">
<form onsubmit="SearchReplaceDialog.searchNext('none');return false;" action="#">
	<div class="tabs">
		<ul>
			<li id="search_tab"><span><a href="javascript:SearchReplaceDialog.switchMode('search');" onmousedown="return false;">{#searchreplace.search_desc}</a></span></li>
			<li id="replace_tab"><span><a href="javascript:SearchReplaceDialog.switchMode('replace');" onmousedown="return false;">{#searchreplace_dlg.replace}</a></span></li>
		</ul>
	</div>

	<div class="panel_wrapper">
		<div id="search_panel" class="panel">
		    <fieldset class="module properties">
                <div class="row first">
                    <div class="column span-4"><label for="search_panel_searchstring" class="required">{#searchreplace_dlg.findwhat}</label></div>
                    <div class="column span-flexible"><input type="text" id="search_panel_searchstring" name="search_panel_searchstring" /></div>
                </div>
                <div class="row inline">
                    <div class="column span-4"><label>{#searchreplace_dlg.direction}</label></div>
                    <div class="column span-flexible">
                        <ul class="radiolist inline">
                            <li><label for="search_panel_backwardsu"><input id="search_panel_backwardsu" name="search_panel_backwards" class="radio" type="radio" /> {#searchreplace_dlg.up}</label></li>
                            <li><label for="search_panel_backwardsd"><input id="search_panel_backwardsd" name="search_panel_backwards" class="radio" type="radio" checked="checked" /> {#searchreplace_dlg.down}</label></li>
                        </ul>
                    </div>
                </div>
                <div class="row inline">
                    <div class="column span-4"><label>&nbsp;</label></div>
                    <div class="column span-flexible">
                        <input id="search_panel_casesensitivebox" name="search_panel_casesensitivebox" type="checkbox" />
                        <label for="search_panel_casesensitivebox"> {#searchreplace_dlg.mcase}</label>
                    </div>
                </div>
            </fieldset>
		</div>

		<div id="replace_panel" class="panel">
		    <fieldset class="module properties">
                <div class="row">
                    <div class="column span-4"><label for="replace_panel_searchstring" class="required">{#searchreplace_dlg.findwhat}</label></div>
                    <div class="column span-flexible"><input type="text" id="replace_panel_searchstring" name="replace_panel_searchstring" /></div>
                </div>
                <div class="row">
                    <div class="column span-4"><label for="replace_panel_replacestring">{#searchreplace_dlg.replacewith}</label></div>
                    <div class="column span-flexible"><input type="text" id="replace_panel_replacestring" name="replace_panel_replacestring" /></div>
                </div>
                <div class="row inline">
                    <div class="column span-4"><label>{#searchreplace_dlg.direction}</label></div>
                    <div class="column span-flexible">
                        <input id="replace_panel_backwardsu" name="replace_panel_backwards" class="radio" type="radio" />
                        <label for="replace_panel_backwardsu">{#searchreplace_dlg.up}</label>
                        <input id="replace_panel_backwardsd" name="replace_panel_backwards" class="radio" type="radio" checked="checked" />
                        <label for="replace_panel_backwardsd">{#searchreplace_dlg.down}</label>
                    </div>
                </div>
                <div class="row inline">
                    <div class="column span-4"><label>&nbsp;</label></div>
                    <div class="column span-flexible">
                        <input id="replace_panel_casesensitivebox" name="replace_panel_casesensitivebox" class="checkbox" type="checkbox" />
                        <label for="replace_panel_casesensitivebox">{#searchreplace_dlg.mcase}</label>
                    </div>
                </div>
            </fieldset>
        </div>

    </div>
    <div class="mceActionPanel module submit-row">
        <ul class="submit-row">
            <li class="cancel-button-container left"><input type="button" id="cancel" class="cancel" name="cancel" value="{#cancel}" onclick="tinyMCEPopup.close();" /></li>
            <li class="submit-button-container"><input type="submit" id="insert" class ="default" name="insert" value="{#searchreplace_dlg.findnext}" /></li>
            <li class="submit-button-container"><input type="button" id="replaceBtn" name="replaceBtn" value="{#searchreplace_dlg.replace}" onclick="SearchReplaceDialog.searchNext('current');" /></li>
            <li class="submit-button-container"><input type="button" id="replaceAllBtn" name="replaceAllBtn" value="{#searchreplace_dlg.replaceall}" onclick="SearchReplaceDialog.searchNext('all');" /></li>
        </ul>
    </div>
</form>
</body>
</html>
