from settings import *

DEBUG = False

ENVIRONMENT = 'production' # admin links will be red

# Indicate your database settings for production here
#
# DATABASES = {
#     'default': {
#         'NAME': '',
#         'ENGINE': 'django.db.backends.mysql',
#         'USER': '',
#         'PASSWORD': '',
#         'HOST': ''
#     }
# }

