from settings import *

ENVIRONMENT = 'staging' # admin links will be orange

# Indicate your database settings for staging here
#
# DATABASES = {
#     'default': {
#         'NAME': '',
#         'ENGINE': 'django.db.backends.mysql',
#         'USER': '',
#         'PASSWORD': '',
#         'HOST': ''
#     }
# }

