/* -----------------------------------------------------------------------

   Grappelli Skin - Tiny MCE
   * based on Tiny MCE http://tinymce.moxiecode.com/
      
   Grappelli Skin - Django Admin Interface
   * http://code.google.com/p/django-grappelli/
   
   Based on Django Admin Interface
   * http://www.djangoproject.com
   
   Developed for Mozilla Firefox 3.0+ / using CSS 3 Specifications
   
   * See README for instructions on how to use Grappelli.
   * For credits and origins, see AUTHORS.
   * This is a compressed file. See the sources in the 'src' directory.
   
   * Copyright (c) 2009, vonautomatisch werkstaetten. All rights reserved.
     See LICENSE for more info.

----------------------------------------------------------------------- */
/* You can extend this CSS by adding your own CSS file with the the content_css option */

/* Import other styles */
@import url('content_base.css');
@import url('content_typography.css');
@import url('content_grid.css');