<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title>{#advanced_dlg.accessibility_help}</title>
		<script type="text/javascript" src="../../tiny_mce_popup.js"></script>
		<script type="text/javascript">tinyMCEPopup.requireLangPack();</script>
	</head>
	<body id="content">
		<h1>{#advanced_dlg.accessibility_usage_title}</h1>
		<h2>Toolbars</h2>
		<p>Press ALT-F10 to move focus to the toolbars. Navigate through the buttons using the arrow keys.
		Press enter to activate a button and return focus to the editor.
		Press escape to return focus to the editor without performing any actions.</p>
		
		<h2>Status Bar</h2>
		<p>To access the editor status bar, press ALT-F11. Use the left and right arrow keys to navigate between elements in the path.
		Press enter or space to select an element. Press escape to return focus to the editor without changing the selection.</p>
		
		<h2>Context Menu</h2>
		<p>Press shift-F10 to activate the context menu. Use the up and down arrow keys to move between menu items. To open sub-menus press the right arrow key.
		To close submenus press the left arrow key.  Press escape to close the context menu.</p>
		
		<h1>Keyboard Shortcuts</h1>
		<table>
			<thead>
				<tr>
					<th>Keystroke</th>
					<th>Function</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td>Control-B</td><td>Bold</td>
				</tr>
				<tr>
					<td>Control-I</td><td>Italic</td>
				</tr>
				<tr>
					<td>Control-Z</td><td>Undo</td>
				</tr>
				<tr>
					<td>Control-Y</td><td>Redo</td>
				</tr>
			</tbody>
		</table>
	</body>
</html>
