<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>{#paste.paste_word_desc}</title>
	<script type="text/javascript" src="../../tiny_mce_popup.js"></script>
	<script type="text/javascript" src="js/pasteword.js"></script>
</head>
<body onresize="PasteWordDialog.resize();" style="display:none; overflow:hidden;">
	<form name="source" onsubmit="return PasteWordDialog.insert();" action="#">
		<div class="title">{#paste.paste_word_desc}</div>

		<div>{#paste_dlg.word_title}</div>

		<div id="iframecontainer"></div>

		<div class="mceActionPanel">
			<input type="submit" id="insert" name="insert" value="{#insert}" />
			<input type="button" id="cancel" name="cancel" value="{#cancel}" onclick="tinyMCEPopup.close();" />
		</div>
	</form>
</body>
</html>
